Documentation
¶
Index ¶
- type Oracle
- func (o *Oracle) EnableResults(scr *indexer.Indexer)
- func (o *Oracle) NewProcess(process *models.Process) ([]byte, error)
- func (o *Oracle) OnComputeResults(results *results.Results, proc *indexertypes.Process, h uint32)
- func (o *Oracle) OnOracleResults(procResults *models.ProcessResult, pid []byte, height uint32)
- type OracleResults
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Oracle ¶
type Oracle struct {
VochainApp *vochain.BaseApplication
// contains filtered or unexported fields
}
func (*Oracle) EnableResults ¶
func (*Oracle) OnComputeResults ¶
OnComputeResults is called once a process result is computed by the indexer. The Oracle will build and send a RESULTS transaction to the Vochain. The transaction includes the final results for the process.
func (*Oracle) OnOracleResults ¶ added in v1.2.1
func (o *Oracle) OnOracleResults(procResults *models.ProcessResult, pid []byte, height uint32)
OnOracleResults does nothing. Required for implementing the indexer EventListener interface
Click to show internal directories.
Click to hide internal directories.